Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: util/misc/uuid.h

Issue 913273002: win: Implementation of CrashReportDatabase for Windows (for C++ Windows readability review) (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: better unlink checks Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « client/crash_report_database_win.cc ('k') | util/misc/uuid.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: util/misc/uuid.h
diff --git a/util/misc/uuid.h b/util/misc/uuid.h
index bbfc771f59b6d6a9183fbdf4b19793ac0c001879..b1b830d917bf15c7f28691dad2e8fcb78a8c35bf 100644
--- a/util/misc/uuid.h
+++ b/util/misc/uuid.h
@@ -19,6 +19,7 @@
#include <string>
+#include "base/strings/string16.h"
#include "base/strings/string_piece.h"
#include "build/build_config.h"
@@ -68,8 +69,8 @@ struct UUID {
std::string ToString() const;
#if defined(OS_WIN)
- //! \brief The same as ToString, but returned as a wstring.
- std::wstring ToWideString() const;
+ //! \brief The same as ToString, but returned as a string16.
+ base::string16 ToString16() const;
#endif // OS_WIN
// These fields are laid out according to RFC 4122 ยง4.1.2.
« no previous file with comments | « client/crash_report_database_win.cc ('k') | util/misc/uuid.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698